# djELMAH

djELMAH catches unhandled exceptions in production-ready Django applications (i.e., `DEBUG=False`) and generates detailed error logs that can be saved locally and/or to any number of remote hosts.

## Acknowledgments

* Inspired by [Elmah](https://github.com/elmah/Elmah) error logging for ASP.NET
